@@ -2,20 +2,22 @@
 
 # Doing this in a separate script lets us do it step by step with a single docker layer.
 
-yum -y install http://rdoproject.org/repos/openstack-liberty/rdo-release-liberty.rpm
-yum update -y \
-    && yum clean all
+if [ -z "$OPENSTACK_RELEASE" ]; then
+    echo "Please, set OPENSTACK_RELEASE to the desired openstack version."
+    echo "You can run the build command as: "
+    echo "OPENSTACK_RELEASE=mitaka docker build -t tripleoupstream/heat-docker-agents:\$OPENSTACK_RELEASE --build-arg OPENSTACK_RELEASE=\$OPENSTACK_RELEASE ."
+    exit 1
+fi
+
+yum -y install http://rdoproject.org/repos/openstack-$OPENSTACK_RELEASE/rdo-release-$OPENSTACK_RELEASE.rpm
+yum update -y
 yum install -y \
         initscripts \
-        dhcp-client \
         ethtool \
         NetworkManager
 
 # We shouldn't need python-zaqarclient here for os-collect-config.
 # The rpm should pull it in but it's not doing that..
-# Also note gcc and python-pip, python-devel, and libyaml-devel are
-# required for docker-compose.  It would be nice to package that or use
-# somethinge else.
 yum install -y \
         openstack-tripleo-puppet-elements \
         openstack-tripleo-image-elements \
@@ -27,36 +29,66 @@ yum install -y \
         os-net-config \
         jq \
         python-zaqarclient \
-        gcc \
-        libyaml-devel \
-        python-devel \
-        python-pip \
         openvswitch \
-        puppet
+        puppet \
+        python-ipaddr
 
-# openstack packages
+# NOTE(flaper87): openstack packages
+# We need these packages just to install the config files.
+# Instead of installing the entire package, we'll extract the
+# config files from the RPM and put them in place. This step will
+# save us ~500 MB in the final size of the image.
+yum install -y --downloadonly --downloaddir=/tmp/packages \
+        openstack-ceilometer-compute \
+        python-nova \
+        openstack-nova-common \
+        openstack-neutron \
+        libvirt-daemon-config-nwfilter \
+        libvirt-daemon-kvm \
+        openstack-nova-compute \
+        openstack-neutron-ml2 \
+        openstack-neutron-openvswitch
+
+CUR=`pwd`
+cd /tmp/packages
+for f in $(ls openstack-*.rpm);
+do
+    rpm2cpio $f | cpio -ivd ./etc/*
+
+    if [ -d 'etc' ];
+    then
+        cp -r etc/* /etc
+        rm -Rf etc
+    fi
+done
+cd $CUR && rm -Rf /tmp/packages
+
+# Also note gcc, python-devel, and libyaml-devel are required for
+# docker-compose. It would be nice to package that or use somethinge else.
+# Working on getting this into centos:7
+# https://admin.fedoraproject.org/pkgdb/package/rpms/docker-compose/
 yum install -y \
-	openstack-ceilometer-compute \
-	python-nova \
-	openstack-nova-common \
-	openstack-neutron \
-	libvirt-daemon-config-nwfilter \
-	libvirt-daemon-kvm \
-	openstack-nova-compute \
-	openstack-neutron-ml2 \
-	openstack-neutron-openvswitch
+    gcc \
+    libyaml-devel \
+    python-devel \
+    python-pip \
+    docker
 
 # heat-config-docker-compose
 # TODO: fix! yet another requirement for docker-compose
 pip install dpath functools32
-yum install -y \
-        docker
-
 
 pip install -U docker-compose
 
-yum clean all
+# NOTE(flaper87): We have to use `rpm --nodeps` because some packages that we
+# depend on happen to depend on python-devel, which we don't need for this
+# container.
+rpm -e --nodeps python-devel
 
+# NOTE(flaper87): Remove unnecessary packages
+yum remove gcc "*-devel"
+yum autoremove -y
+yum clean all
 
 # Heat config setup.
 mkdir -p /var/lib/heat-config/hooks
